#[non_exhaustive]pub struct RecentEmojiEventContent {
pub recent_emoji: Vec<RecentEmoji>,
}Available on crate feature
events only.Expand description
The content of an m.recent_emoji event.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.recent_emoji: Vec<RecentEmoji>The list of recently used emojis, ordered by last usage time.
Implementations
Sourceimpl RecentEmojiEventContent
impl RecentEmojiEventContent
Sourcepub const RECOMMENDED_MAX_LEN: usize = 100
pub const RECOMMENDED_MAX_LEN: usize = 100
The maximum length of the list recommended in the Matrix specification.
Sourcepub fn new(recent_emoji: Vec<RecentEmoji>) -> RecentEmojiEventContent
pub fn new(recent_emoji: Vec<RecentEmoji>) -> RecentEmojiEventContent
Creates a new RecentEmojiEventContent from the given list.
Sourcepub fn increment_emoji_total(&mut self, emoji: &str)
pub fn increment_emoji_total(&mut self, emoji: &str)
Increment the total for the given emoji.
If the emoji is in the list, its total is incremented and it is moved to the start of the list.
If the emoji is not in the list, it is added at the start of the list with a total set to
1.
If the length of the list is bigger than RECOMMENDED_MAX_LEN,
the list is truncated.
Sourcepub fn recent_emoji_sorted_by_total(&self) -> Vec<RecentEmoji>
pub fn recent_emoji_sorted_by_total(&self) -> Vec<RecentEmoji>
Get the list of recent emoji sorted by the number of uses.
When several emoji have the same number of uses they are sorted by last usage time.
The returned list is truncated to RECOMMENDED_MAX_LEN.